@@ -5,7 +5,6 @@ import (
 	"io/ioutil"
 	"log"
 	"os"
-	"runtime"
 	"sync"
 
 	"os/exec"
@@ -30,8 +29,8 @@ import (
 	"github.com/jesseduffield/lazygit/pkg/theme"
 	"github.com/jesseduffield/lazygit/pkg/updates"
 	"github.com/jesseduffield/lazygit/pkg/utils"
-	"github.com/mattn/go-runewidth"
 	"github.com/sirupsen/logrus"
+	"gopkg.in/ozeidan/fuzzy-patricia.v3/patricia"
 )
 
 // screen sizing determines how much space your selected window takes up (window
@@ -51,10 +50,6 @@ const StartupPopupVersion = 5
 // OverlappingEdges determines if panel edges overlap
 var OverlappingEdges = false
 
-func init() {
-	runewidth.DefaultCondition.EastAsianWidth = false
-}
-
 type ContextManager struct {
 	ContextStack []Context
 	sync.RWMutex
@@ -122,6 +117,8 @@ type Gui struct {
 
 	// the extras window contains things like the command log
 	ShowExtrasWindow bool
+
+	suggestionsAsyncHandler *tasks.AsyncHandler
 }
 
 type listPanelState struct {
@@ -342,6 +339,9 @@ type guiState struct {
 
 	// flag as to whether or not the diff view should ignore whitespace
 	IgnoreWhitespaceInDiffView bool
+
+	// for displaying suggestions while typing in a file name
+	FilesTrie *patricia.Trie
 }
 
 // reuseState determines if we pull the repo state from our repo state map or
@@ -418,6 +418,7 @@ func (gui *Gui) resetState(filterPath string, reuseState bool) {
 		// TODO: put contexts in the context manager
 		ContextManager: NewContextManager(initialContext),
 		Contexts:       contexts,
+		FilesTrie:      patricia.NewTrie(),
 	}
 
 	gui.RepoStateMap[Repo(currentDir)] = gui.State
@@ -427,19 +428,20 @@ func (gui *Gui) resetState(filterPath string, reuseState bool) {
 // NewGui builds a new gui handler
 func NewGui(log *logrus.Entry, gitCommand *commands.GitCommand, oSCommand *oscommands.OSCommand, tr *i18n.TranslationSet, config config.AppConfigurer, updater *updates.Updater, filterPath string, showRecentRepos bool) (*Gui, error) {
 	gui := &Gui{
-		Log:                  log,
-		GitCommand:           gitCommand,
-		OSCommand:            oSCommand,
-		Config:               config,
-		Tr:                   tr,
-		Updater:              updater,
-		statusManager:        &statusManager{},
-		viewBufferManagerMap: map[string]*tasks.ViewBufferManager{},
-		showRecentRepos:      showRecentRepos,
-		RepoPathStack:        []string{},
-		RepoStateMap:         map[Repo]*guiState{},
-		CmdLog:               []string{},
-		ShowExtrasWindow:     config.GetUserConfig().Gui.ShowCommandLog,
+		Log:                     log,
+		GitCommand:              gitCommand,
+		OSCommand:               oSCommand,
+		Config:                  config,
+		Tr:                      tr,
+		Updater:                 updater,
+		statusManager:           &statusManager{},
+		viewBufferManagerMap:    map[string]*tasks.ViewBufferManager{},
+		showRecentRepos:         showRecentRepos,
+		RepoPathStack:           []string{},
+		RepoStateMap:            map[Repo]*guiState{},
+		CmdLog:                  []string{},
+		ShowExtrasWindow:        config.ShowCommandLogOnStartup(),
+		suggestionsAsyncHandler: tasks.NewAsyncHandler(),
 	}
 
 	gui.resetState(filterPath, false)
@@ -497,8 +499,6 @@ func (gui *Gui) Run() error {
 	g.NextSearchMatchKey = gui.getKey(userConfig.Keybinding.Universal.NextMatch)
 	g.PrevSearchMatchKey = gui.getKey(userConfig.Keybinding.Universal.PrevMatch)
 
-	g.ASCII = runtime.GOOS == "windows" && runewidth.IsEastAsian()
-
 	g.ShowListFooter = userConfig.Gui.ShowListFooter
 
 	if userConfig.Gui.MouseEvents {
